@@ -164,6 +164,7 @@ test_that("multinomial fit and predict work", {
       group = "id",
       chains = 1,
       iter = 1,
+      backend = "rstan",
       algorithm = "Fixed_param",
       init = list(init),
     ),
@@ -479,12 +480,7 @@ test_that("update without recompile works", {
     chains = 2,
     cores = 2,
     refresh = 0,
-    save_warmup = FALSE,
-    pars = c(
-      "omega_alpha_1_y", "omega_raw_alpha_y", "nu_raw", "nu", "L",
-      "sigma_nu", "a_y"
-    ),
-    include = FALSE
+    save_warmup = FALSE
   )
   expect_error(
     fit <- update(
@@ -523,12 +519,8 @@ test_that("custom stan model works", {
     chains = 2,
     cores = 2,
     refresh = 0,
-    save_warmup = FALSE,
-    pars = c(
-      "omega_alpha_1_y", "omega_raw_alpha_y", "nu_raw", "nu", "L",
-      "sigma_nu", "a_y"
-    ),
-    include = FALSE
+    backend = "rstan",
+    save_warmup = FALSE
   )
   code <- get_code(initial_fit)
   set.seed(1)
@@ -548,11 +540,7 @@ test_that("custom stan model works", {
       cores = 2,
       refresh = 0,
       save_warmup = FALSE,
-      pars = c(
-        "omega_alpha_1_y", "omega_raw_alpha_y", "nu_raw", "nu", "L",
-        "sigma_nu", "a_y"
-      ),
-      include = FALSE,
+      backend = "rstan",
       custom_stan_model = code
     ),
     NA
@@ -648,12 +636,7 @@ test_that("information on >2 chains is summarized in print", {
     thin = 10,
     chains = 4,
     refresh = 0,
-    save_warmup = FALSE,
-    pars = c(
-      "omega_alpha_1_y", "omega_raw_alpha_y", "nu_raw", "nu", "L",
-      "sigma_nu", "a_y"
-    ),
-    include = FALSE
+    save_warmup = FALSE
   )
   out <- capture_all_output(print(fit))
   expect_true(
@@ -669,8 +652,9 @@ test_that("information on >2 chains is summarized in print", {
 
 
 test_that("latent factor models are identifiable", {
+  # Skip for now
+  skip()
   skip_if_not(run_extended_tests)
-  skip_on_os("windows") # Fails for Windows for some reason
 
   generate_data <- function(N, T_, D, alpha, mean_lambda, sd_lambda, sd_alpha) {
     y <- matrix(0, N, T_)
@@ -730,11 +714,9 @@ test_that("latent factor models are identifiable", {
   set.seed(2)
   sim <- generate_data(
     100, 50, 20,
-    alpha = 0, mean_lambda = 1, sd_lambda = 0.1, sd_alpha = 2
-  )
+    alpha = 0, mean_lambda = 1, sd_lambda = 0.1, sd_alpha = 2)
   dformula <- obs(y ~ -1 + x + random(~ 1), family = "gaussian") +
-    lfactor() +
-    splines(20)
+    lfactor() + splines(20)
   priors <- get_priors(dformula, data = sim$data, time = "time", group = "id")
   priors$prior[priors$parameter != "kappa_y"] <- "normal(0, 5)"
   fit2 <- dynamite(
@@ -758,11 +740,9 @@ test_that("latent factor models are identifiable", {
   set.seed(3)
   sim <- generate_data(
     100, 50, 20,
-    alpha = -1, mean_lambda = 0.5, sd_lambda = 2, sd_alpha = 0
-  )
+    alpha = -1, mean_lambda = 0.5, sd_lambda = 2, sd_alpha = 0)
   dformula <- obs(y ~ x, family = "gaussian") +
-    lfactor() +
-    splines(20)
+    lfactor() + splines(20)
   priors <- get_priors(dformula, data = sim$data, time = "time", group = "id")
   priors$prior[priors$parameter != "kappa_y"] <- "normal(0, 5)"
   # need some informativeness on prior of kappa (or zeta?)
@@ -789,8 +769,7 @@ test_that("latent factor models are identifiable", {
   set.seed(4)
   sim <- generate_data(
     100, 50, 20,
-    alpha = 0, mean_lambda = -1, sd_lambda = 0.5, sd_alpha = 0.5
-  )
+    alpha = 0, mean_lambda = -1, sd_lambda = 0.5, sd_alpha = 0.5)
   dformula <- obs(y ~ x + random(~ 1), family = "gaussian") +
     lfactor() + splines(20)
   priors <- get_priors(dformula, data = sim$data, time = "time", group = "id")
@@ -817,11 +796,9 @@ test_that("latent factor models are identifiable", {
   set.seed(5)
   sim <- generate_data(
     100, 50, 20,
-    alpha = 1, mean_lambda = 0, sd_lambda = 0.5, sd_alpha = 1
-  )
+    alpha = 1, mean_lambda = 0, sd_lambda = 0.5, sd_alpha = 1)
   dformula <- obs(y ~ x + random(~ 1), family = "gaussian") +
-    lfactor(nonzero_lambda = FALSE) +
-    splines(20)
+    lfactor(nonzero_lambda = FALSE) + splines(20)
   priors <- get_priors(dformula, data = sim$data, time = "time", group = "id")
   priors$prior[] <- "normal(0, 5)"
   fit5 <- dynamite(
@@ -849,8 +826,7 @@ test_that("latent factor models are identifiable", {
     alpha = 1, mean_lambda = 0, sd_lambda = 0.5, sd_alpha = 0
   )
   dformula <- obs(y ~ x, family = "gaussian") +
-    lfactor(nonzero_lambda = FALSE) +
-    splines(20)
+    lfactor(nonzero_lambda = FALSE) + splines(20)
   priors <- get_priors(dformula, data = sim$data, time = "time", group = "id")
   priors$prior[] <- "normal(0, 5)"
   fit6 <- dynamite(
@@ -903,8 +879,7 @@ test_that("latent factor models are identifiable", {
   )
   dformula <- obs(y ~ 1, family = "gaussian") +
     obs(x ~ 1, family = "gaussian") +
-    lfactor(nonzero_lambda = FALSE, flip_sign = TRUE) +
-    splines(10)
+    lfactor(nonzero_lambda = FALSE, flip_sign = TRUE) + splines(10)
   fit <- dynamite(
     dformula,
     data = d, time = "time", group = "id",
